==> fispro_3.4.orig.tar.gz: fispro-3.4/cpp/hfp/mainhfpsr.cpp <==
//**********************************************************************
//
//
//                              MAINHFPSR.CPP
//
//
// Author(s) : Serge GUILLAUME, Brigitte CHARNOMORDIC 
// FISPRO Version : 3.2 - Copyright INRA - Cemagref - 2002 - IDDN.FR.001.030024.000.R.P.2005.003.31235
// Licence http://www.cecill.info/licences/Licence_CeCILL_V2-en.html/
// Last modification date:  July 31, 2009 - Contact : fispro@supagro.inra.fr
// File : Main file for generating a FIS configuration file for hfp data,
//        (configuration and vertex files) 
//        Fispro, part of package hfp (Hierarchical fuzzy partitioning)
//        requires library fispro
//
//**********************************************************************

#include "hfpfis.h"
#include "sethfpfis.h"

int main(int argc, char ** argv)
//******************************
{
  if(argc < 8)
    {
      printf("\nThe program %s needs 9 argument(s) : ", argv[0]);
      printf("\n\t* the data file name;\n") ;
      printf("\n\t* the number of mf for each input variable (string with space separator);");
      printf("\n\t* the input hierarchy type : 1 hfp, 2 kmeans, 3 regular");
      printf("\n\t* the input tolerance equality threshold (<1) or the number of groups (>1)");
      printf("\n\t* the number of mf for the ouput variable (if nmf=0 output crisp);");
      printf("\n\t* the output hierarchy type : 1 hfp, 2 kmeans, 3 regular");
      printf("\n\t* the defuzzification type (valid strings depend on the output type)");
      printf("\n\t* the disjunction type (valid strings : sum, max)");
      printf("\n\t* the output tolerance equality threshold (<1) or the number of groups (>1)");
      

      printf("\n\t\tOptions:");
      printf("\n\t\t  -o the result output file name (default:  'Name'-sr.fis)");
      printf("\n\t\t  -c the conjunction type (default:  'prod')");
      printf("\n\t\t  -v the existing vertex file name, inputs only (default:  it is computed)");      printf("\n\t\t  -f set classification flag for the output (default:  false)");
      printf("\n\t\t     (Valid only when #output mf  = 0)");

      printf("\n");
      return 1;
    }

  FISHFP *S=NULL;
  char * Config = NULL;
  char * Conj = NULL;
  char * VertexF = NULL;
  int i, clas = false;
  char *ch1 = NULL;
  char *ch2 = NULL;
  char *ch3 = NULL;
  char *MFstr = NULL;

  double t;

  t = strtod(argv[4], NULL);
  if(t < 0.) t = 0.01;

  try
    {
      ch1 = new char [strlen(argv[1]) + 10];
      ch2 = new char [strlen(argv[1]) + 10];
      ch3 = new char [strlen(argv[1]) + 10];

      for(i = 9; i < argc; i++)
	{
	if(! strncmp("-o", argv[i], 2) && strlen(argv[i]) > 3)
	  Config = argv[i] + 2;
	else if(! strncmp("-c", argv[i], 2) && strlen(argv[i]) > 3) 
	  Conj = argv[i] + 2;
	else if(! strncmp("-v", argv[i], 2) && strlen(argv[i]) > 3) 
	  VertexF = argv[i] + 2;
	else if(! strncmp("-f", argv[i], 2)) clas = true;
	}

      //hfpcfg iris 1 iris.t.hfp [1-3]
      sprintf(ch1, "%s.t.hfp", argv[1]);
      S = new FISHFP (argv[1], 1, ch1, atoi(argv[3]));
      S->SetToleranceThres(t);
      if(Conj) S->SetConjunction(Conj);
      S->PrintCfgHfp(argv[1], ch1);
      delete S;

      sprintf(ch3, "%s.hfp", argv[1]);
      MFstr=new char[strlen(argv[2])+3];
      sprintf(MFstr,"%s ",argv[2]);// add white space at the end for single input case
      SetHfpFis(ch1,MFstr , ch3);
 
      if(VertexF == NULL)
	{
	  // hfpvertex iris iris.t.hfp -k100 -oiris.vertex
	  S = new FISHFP (argv[1], ch3);
	  sprintf(ch2, "%s.vertex", argv[1]);
	  S->Hierarchy(ch2);
	  delete S;
	  VertexF = ch2;
	}

      remove (ch1);

      t = strtod(argv[9], NULL);
      if(t < 0.) t = 0.01;

      if(!Config)
	{
	  sprintf(ch1, "%s-sr.fis", argv[1]);
	  Config = ch1;
	}
      S = new FISHFP (ch3, argv[1], Config);
      S->SetVertexFile(VertexF);
      S->GenereCfgFisSr(atoi(argv[5]), atoi(argv[6]), argv[7], argv[8], t, clas);
      delete S;
    }      

  catch(std::exception &e)
    {
      printf("\n%s", e.what());
    }


  delete [] ch1; delete [] ch2; delete [] ch3;delete [] MFstr;
  return 0;
}

==> fispro_3.6.orig.tar.gz: fispro-3.6/cpp/hfp/mainhfpsr.cpp <==
//**********************************************************************
//
//
//                              MAINHFPSR.CPP
//
//
// Author(s) : Serge GUILLAUME, Brigitte CHARNOMORDIC 
// FISPRO Version : 3.2 - Copyright INRA - Cemagref - 2002 - IDDN.FR.001.030024.000.R.P.2005.003.31235
// Licence http://www.cecill.info/licences/Licence_CeCILL_V2-en.html/
// Last modification date:  July 31, 2009 - Contact : fispro@supagro.inra.fr
// File : Main file for generating a FIS configuration file for hfp data,
//        (configuration and vertex files) 
//        Fispro, part of package hfp (Hierarchical fuzzy partitioning)
//        requires library fispro
//
//**********************************************************************

#include "hfpfis.h"
#include "sethfpfis.h"

int main(int argc, char ** argv)
//******************************
{
  if(argc < 8)
    {
      printf("\nThe program %s needs 9 argument(s) : ", argv[0]);
      printf("\n\t* the data file name;\n") ;
      printf("\n\t* the number of mf for each input variable (string with space separator);");
      printf("\n\t* the input hierarchy type : 1 hfp, 2 kmeans, 3 regular");
      printf("\n\t* the input tolerance equality threshold (<1) or the number of groups (>1)");
      printf("\n\t* the number of mf for the ouput variable (if nmf=0 output crisp);");
      printf("\n\t* the output hierarchy type : 1 hfp, 2 kmeans, 3 regular");
      printf("\n\t* the defuzzification type (valid strings depend on the output type)");
      printf("\n\t* the disjunction type (valid strings : sum, max)");
      printf("\n\t* the output tolerance equality threshold (<1) or the number of groups (>1)");
      

      printf("\n\t\tOptions:");
      printf("\n\t\t  -o the result output file name (default:  'Name'-sr.fis)");
      printf("\n\t\t  -c the conjunction type (default:  'min')");
      printf("\n\t\t  -v the existing vertex file name, inputs only (default:  it is computed)");      printf("\n\t\t  -f set classification flag for the output (default:  false)");
      printf("\n\t\t     (Valid only when #output mf  = 0)");

      printf("\n");
      return 1;
    }

  FISHFP *S=NULL;
  char * Config = NULL;
  char * Conj = NULL;
  char * VertexF = NULL;
  int i, clas = false;
  char *ch1 = NULL;
  char *ch2 = NULL;
  char *ch3 = NULL;
  char *MFstr = NULL;

  double t;

  t = strtod(argv[4], NULL);
  if(t < 0.) t = 0.01;

  try
    {
      ch1 = new char [strlen(argv[1]) + 10];
      ch2 = new char [strlen(argv[1]) + 10];
      ch3 = new char [strlen(argv[1]) + 10];

      for(i = 9; i < argc; i++)
	{
	if(! strncmp("-o", argv[i], 2) && strlen(argv[i]) > 3)
	  Config = argv[i] + 2;
	else if(! strncmp("-c", argv[i], 2) && strlen(argv[i]) > 3) 
	  Conj = argv[i] + 2;
	else if(! strncmp("-v", argv[i], 2) && strlen(argv[i]) > 3) 
	  VertexF = argv[i] + 2;
	else if(! strncmp("-f", argv[i], 2)) clas = true;
	}

      //hfpcfg iris 1 iris.t.hfp [1-3]
      sprintf(ch1, "%s.t.hfp", argv[1]);
      S = new FISHFP (argv[1], 1, ch1, atoi(argv[3]));
      S->SetToleranceThres(t);
      if(Conj) S->SetConjunction(Conj);
      S->PrintCfgHfp(argv[1], ch1);
      delete S;

      sprintf(ch3, "%s.hfp", argv[1]);
      MFstr=new char[strlen(argv[2])+3];
      sprintf(MFstr,"%s ",argv[2]);// add white space at the end for single input case
      SetHfpFis(ch1,MFstr , ch3);
 
      if(VertexF == NULL)
	{
	  // hfpvertex iris iris.t.hfp -k100 -oiris.vertex
	  S = new FISHFP (argv[1], ch3);
	  sprintf(ch2, "%s.vertex", argv[1]);
	  S->Hierarchy(ch2);
	  delete S;
	  VertexF = ch2;
	}

      remove (ch1);

      t = strtod(argv[9], NULL);
      if(t < 0.) t = 0.01;

      if(!Config)
	{
	  sprintf(ch1, "%s-sr.fis", argv[1]);
	  Config = ch1;
	}
      S = new FISHFP (ch3, argv[1], Config);
      S->SetVertexFile(VertexF);
      S->GenereCfgFisSr(atoi(argv[5]), atoi(argv[6]), argv[7], argv[8], t, clas);
      delete S;
      if(VarNameG != NULL) 
	{
	  for(int j = 0; j < NbVarG; j++)
	    if(VarNameG[j] != NULL)  delete [] VarNameG[j];
	  delete [] VarNameG;
	  VarNameG = NULL;
	}
     
    }      

  catch(std::exception &e)
    {
      printf("\n%s", e.what());
    }


  delete [] ch1; delete [] ch2; delete [] ch3;delete [] MFstr;
  return 0;
}
